using System.Text.Json;
using System.Text.RegularExpressions;
using HermesSocketLibrary.Requests.Messages;
using Serilog;

namespace TwitchChatTTS.Hermes.Socket.Requests
{
    public class CreateTTSFilterAck : IRequestAck
    {
        public string Name => "create_tts_filter";
        private readonly User _user;
        private readonly JsonSerializerOptions _options;
        private readonly ILogger _logger;

        public CreateTTSFilterAck(User user, JsonSerializerOptions options, ILogger logger)
        {
            _user = user;
            _options = options;
            _logger = logger;
        }

        public void Acknowledge(string requestId, string? json, IDictionary<string, object>? requestData)
        {
            if (json == null)
            {
                _logger.Warning($"TTS Filter JSON data received is null.");
                return;
            }

            var filter = JsonSerializer.Deserialize<TTSWordFilter>(json, _options);
            if (filter == null)
            {
                _logger.Warning($"TTS Filter data received is null.");
                return;
            }

            if (_user.RegexFilters.Any(f => f.Id == filter.Id))
            {
                _logger.Warning($"Filter already exists [filter id: {filter.Id}]");
                return;
            }

            try
            {
                var re = new Regex(filter.Search, ((RegexOptions)filter.Flag) | RegexOptions.Compiled);
                re.Match(string.Empty);
                filter.Regex = re;
            }
            catch (Exception)
            {
                _logger.Warning($"Failed to generate a Regular Expression using '{filter.Search}' [filter id: {filter.Id}]");
            }

            _logger.Debug($"Filter data [filter id: {filter.Id}][search: {filter.Search}][replace: {filter.Replace}]");
            _user.RegexFilters.Add(filter);
            _logger.Information($"Filter has been created [filter id: {filter.Id}]");
        }
    }
}